@@ -51,6 +51,7 @@ This module is providing/pre-defining the following application state variables:
     * :attr:`~MainAppBase.lang_code`
     * :attr:`~MainAppBase.light_theme`
     * :attr:`~MainAppBase.sound_volume`
+    * :attr:`~MainAppBase.vibration_volume`
     * :attr:`~MainAppBase.win_rectangle`
 
 Which app state variables are finally used by your app project is (fully data-driven) depending on the app state
@@ -312,7 +313,7 @@ from ae.core import DEBUG_LEVELS                                    # type: igno
 from ae.console import ConsoleApp                                   # type: ignore
 
 
-__version__ = '0.1.41'
+__version__ = '0.1.42'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -450,6 +451,7 @@ class MainAppBase(ConsoleApp, ABC):
     lang_code: str = ""                                     #: optional language code (e.g. 'es_ES' for Spanish)
     light_theme: bool = False                               #: True=light theme/background, False=dark theme
     sound_volume: float = 0.12                              #: sound volume of current app (0.0=mute, 1.0=max)
+    vibration_volume: float = 0.3                           #: vibration volume of current app (0.0=mute, 1.0=max)
     win_rectangle: tuple = (0, 0, 800, 600)                 #: window coordinates (x, y, width, height)
 
     # optional generic run-time shortcut references
@@ -575,17 +577,6 @@ class MainAppBase(ConsoleApp, ABC):
         self.set_opt('debug_level', level)
         return True
 
-    def on_font_size_change(self, font_size_lit: str, _event_kwargs: Dict[str, Any]) -> bool:
-        """ font size app state change event handler.
-
-        :param font_size_lit:   font size as string.
-        :param _event_kwargs:   unused event kwargs.
-        :return:                True for to confirm change of flow id.
-        """
-        self.vpo(f"MainAppBase.on_font_size_change {font_size_lit}")
-        self.change_app_state('font_size', float(font_size_lit))
-        return True
-
     def on_lang_code_change(self, lang_code: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ language app state change event handler.
 
